package example.codes;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.silanis.esl.sdk.*;
import com.silanis.esl.sdk.builder.*;

import static com.silanis.esl.sdk.builder.DocumentVisibilityBuilder.newDocumentVisibility;
import static com.silanis.esl.sdk.builder.DocumentVisibilityConfigurationBuilder.newDocumentVisibilityConfiguration;

public class DocumentVisibility {
	

	private final static String DOC1_ID = "doc1";
	private final static String DOC2_ID = "doc2";

	private final static String SIGNER1_ID = "Signer1";
	private final static String SIGNER2_ID = "Signer2";

	public static void main(String[] args) {
		
		EslClient eslClient = new EslClient(MyInfo.API_KEY_SANDBOX, MyInfo.API_URL_SANDBOX);
		
		DocumentPackage superDuperPackage = PackageBuilder.newPackageNamed("DocumentVisibilityExample " + new SimpleDateFormat("HH:mm:ss").format(new Date()))
	            .describedAs("This is a package created using the eSignLive SDK")
	            .withSigner(SignerBuilder.newSignerWithEmail("mail31@mailinator.com")
	                            .withCustomId(SIGNER1_ID)
	                            .withFirstName("John1")
	                            .withLastName("Smith1"))
	            .withSigner(SignerBuilder.newSignerWithEmail("mail32@mailinator.com")
	                            .withCustomId(SIGNER2_ID)
	                            .withFirstName("John2")
	                            .withLastName("Smith2"))
	            .withDocument(DocumentBuilder.newDocumentWithName("Document1")
	                              .withId(DOC1_ID)
	                              .fromFile("C:/Users/hhaidary/Desktop/PDFs/sample_contract.pdf")
	                              .withSignature(SignatureBuilder.signatureFor("mail31@mailinator.com")
	                                                 .onPage(0)
	                                                 .atPosition(100, 100)))
	            .withDocument(DocumentBuilder.newDocumentWithName("Document2")
	                              .withId(DOC2_ID)
	                              .fromFile("C:/Users/hhaidary/Desktop/PDFs/cleaning_contract.pdf")
	                              .withSignature(SignatureBuilder.signatureFor("mail32@mailinator.com")
	                                                 .onPage(0)
	                                                 .atPosition(100, 100)))
	            .build();

	        PackageId packageId = eslClient.createPackage(superDuperPackage);
	        
	        //Create list of signers for visibility of first document. 
	        List<String> signerIdsList1 = new ArrayList<String>();
	        signerIdsList1.add(SIGNER1_ID);
	        
	        //Create list of signers for visibility of second document.
	        List<String> signerIdsList2 = new ArrayList<String>();
	        signerIdsList2.add(SIGNER2_ID);
	        
	        com.silanis.esl.sdk.DocumentVisibility visibility = newDocumentVisibility()
	            .addConfiguration(newDocumentVisibilityConfiguration(DOC1_ID)
	            		.withSignerIds(signerIdsList1))
	            .addConfiguration(newDocumentVisibilityConfiguration(DOC2_ID)
	            		.withSignerIds(signerIdsList2))
	            .build();
	        
	        //Configure document visibility.
	        eslClient.configureDocumentVisibility(packageId, visibility);
	        
	        eslClient.sendPackage(packageId);
	        
	        System.out.println(packageId);
	        
	}

}
